==> acceleratedrendering-1.0.5.1-1.21.1-alpha-fabric.1-sources.jar: com/github/argon4w/acceleratedrendering/features/filter/mixins/BlockEntityRenderDispatcherMixin.java <==
package com.github.argon4w.acceleratedrendering.features.filter.mixins;

import com.github.argon4w.acceleratedrendering.features.entities.AcceleratedEntityRenderingFeature;
import com.github.argon4w.acceleratedrendering.features.filter.FilterFeature;
import com.github.argon4w.acceleratedrendering.features.items.AcceleratedItemRenderingFeature;
import com.github.argon4w.acceleratedrendering.features.text.AcceleratedTextRenderingFeature;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import net.minecraft.class_2586;
import net.minecraft.class_824;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_824.class)
public class BlockEntityRenderDispatcherMixin {

	@WrapOperation(
			method	= "tryRender",
			at		= @At(
					value	= "INVOKE",
					target	= "Ljava/lang/Runnable;run()V"
			)
	)
	private static void filterBlockEntity(Runnable instance, Operation<Void> original, @Local(argsOnly = true, ordinal = 0) class_2586 blockEntity) {
		var pass =	!	FilterFeature.isEnabled					()
				||	!	FilterFeature.shouldFilterBlockEntities	()
				||		FilterFeature.testBlockEntity			(blockEntity);

		if (!pass) {
			AcceleratedEntityRenderingFeature	.useVanillaPipeline();
			AcceleratedItemRenderingFeature		.useVanillaPipeline();
			AcceleratedTextRenderingFeature		.useVanillaPipeline();
		}

		original.call(instance);

		if (!pass) {
			AcceleratedEntityRenderingFeature	.resetPipeline();
			AcceleratedItemRenderingFeature		.resetPipeline();
			AcceleratedTextRenderingFeature		.resetPipeline();
		}
	}
}

==> acceleratedrendering-1.0.7-1.21.1-alpha-fabric.1-sources.jar: com/github/argon4w/acceleratedrendering/features/filter/mixins/BlockEntityRenderDispatcherMixin.java <==
package com.github.argon4w.acceleratedrendering.features.filter.mixins;

import com.github.argon4w.acceleratedrendering.features.entities.AcceleratedEntityRenderingFeature;
import com.github.argon4w.acceleratedrendering.features.filter.FilterFeature;
import com.github.argon4w.acceleratedrendering.features.items.AcceleratedItemRenderingFeature;
import com.github.argon4w.acceleratedrendering.features.text.AcceleratedTextRenderingFeature;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.minecraft.class_2586;
import net.minecraft.class_824;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_824.class)
public class BlockEntityRenderDispatcherMixin {

	@WrapOperation(
			method	= "tryRender",
			at		= @At(
					value	= "INVOKE",
					target	= "Ljava/lang/Runnable;run()V"
			)
	)
	private static void filterBlockEntity(
			Runnable		instance,
			Operation<Void>	original,
			class_2586		blockEntity
	) {
		var pass =	!	FilterFeature.isEnabled					()
				||	!	FilterFeature.shouldFilterBlockEntities	()
				||		FilterFeature.testBlockEntity			(blockEntity);

		if (!pass) {
			AcceleratedEntityRenderingFeature	.useVanillaPipeline();
			AcceleratedItemRenderingFeature		.useVanillaPipeline();
			AcceleratedTextRenderingFeature		.useVanillaPipeline();
		}

		original.call(instance);

		if (!pass) {
			AcceleratedEntityRenderingFeature	.resetPipeline();
			AcceleratedItemRenderingFeature		.resetPipeline();
			AcceleratedTextRenderingFeature		.resetPipeline();
		}
	}
}
